@@ -17,8 +17,8 @@ package Dist::Zilla::Plugin::TemplateCJM;
 # ABSTRACT: Process templates, including version numbers & changes
 #---------------------------------------------------------------------
 
-our $VERSION = '4.22';
-# This file is part of Dist-Zilla-Plugin-TemplateCJM 4.22 (April 26, 2014)
+our $VERSION = '4.23';
+# This file is part of Dist-Zilla-Plugin-TemplateCJM 4.23 (July 11, 2015)
 
 
 use Moose;
@@ -131,6 +131,7 @@ sub setup_installer {
     $self->log('Processing ' . $file->name);
     $self->_cur_filename($file->name);
     $self->_cur_offset(0);
+    $self->_store_pathname(\%data, $file);
     $file->content($self->fill_in_string($file->content, \%data, \%parms));
   } # end foreach $file
 
@@ -142,6 +143,17 @@ sub setup_installer {
   } # end foreach $file
 } # end setup_installer
 
+#---------------------------------------------------------------------
+# Store pathname and filename in the data hash
+
+sub _store_pathname
+{
+  my ($self, $dataRef, $file) = @_;
+
+  $dataRef->{pathname} = $dataRef->{filename} = $file->name;
+  $dataRef->{filename} =~ s!^.*/!!s; # Strip directory names
+} # end _store_pathname
+
 #---------------------------------------------------------------------
 # Make sure we have a release date:
 
@@ -285,6 +297,7 @@ sub munge_file
   $dataRef->{version} = "$version";
   $dataRef->{module}  = $pm_info->name || $dataRef->{module};
   $dataRef->{pm_info} = \$pm_info;
+  $self->_store_pathname($dataRef, $file);
 
   $parmsRef->{FILENAME} = $pmFile;
 
@@ -454,8 +467,8 @@ Dist::Zilla::Plugin::TemplateCJM - Process templates, including version numbers
 
 =head1 VERSION
 
-This document describes version 4.22 of
-Dist::Zilla::Plugin::TemplateCJM, released April 26, 2014.
+This document describes version 4.23 of
+Dist::Zilla::Plugin::TemplateCJM, released July 11, 2015.
 
 =head1 SYNOPSIS
 
@@ -521,10 +534,20 @@ C<undef> if the release date could not be parsed as a date.
 
 The name of the distribution.
 
+=item C<$filename>
+
+The filename of the file being processed, with any directory names omitted.
+See also C<$pathname>.
+
 =item C<%meta>
 
 The hash of metadata that will be stored in F<META.yml>.
 
+=item C<$pathname>
+
+The pathname of the file being processed, relative to the distribution
+root in Unix format (forward slashes).  See also C<$filename>.
+
 =item C<$t>
 
 The TemplateCJM object that is processing the template.
@@ -735,7 +758,7 @@ L<< https://github.com/madsen/dist-zilla-plugin-templatecjm >>.
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Christopher J. Madsen.
+This software is copyright (c) 2015 by Christopher J. Madsen.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
